![Logo_DeSota](https://github.com/DeSOTAai/pip/assets/140865429/6fc2c7e2-bea0-4823-8ce2-4dfed8d974a6)
# DeSOTA Preferred Installer Program
```
pip install desota
```

# Packages
## detools
```
from desota import detools
```
### Tool Methods

* [detools.get_model_req](https://github.com/DeSOTAai/pip/blob/7bcc88958e23d32eaa45b99284fdafc15b6b5c54/src/desota/detools.py#L96)

    Converts the model request, a YAML file created BY [DeRunner](https://github.com/DeSOTAai/DeRunner), into a python dictionary.

---

* [detools.get_model_args](https://github.com/DeSOTAai/pip/blob/7bcc88958e23d32eaa45b99284fdafc15b6b5c54/src/desota/detools.py#L121)

    Get Pro-Arguments from DeSOTA Model request

---
---

### Model Methods

* [detools.get_request_audio](https://github.com/DeSOTAai/pip/blob/7bcc88958e23d32eaa45b99284fdafc15b6b5c54/src/desota/detools.py#L220)

    Get (download) Audio Arguments from DeSOTA Model request

---

* [detools.get_request_video](https://github.com/DeSOTAai/pip/blob/7bcc88958e23d32eaa45b99284fdafc15b6b5c54/src/desota/detools.py#L249)

    Get (download) Video Arguments from DeSOTA Model request

---

* [detools.get_request_image](https://github.com/DeSOTAai/pip/blob/7bcc88958e23d32eaa45b99284fdafc15b6b5c54/src/desota/detools.py#L191)

    Get (download) Image Arguments from DeSOTA Model request

---

* [detools.get_request_file](https://github.com/DeSOTAai/pip/blob/7bcc88958e23d32eaa45b99284fdafc15b6b5c54/src/desota/detools.py#L171)

    Get (download) File Arguments from DeSOTA Model request

---

* [detools.get_request_qa](https://github.com/DeSOTAai/pip/blob/7bcc88958e23d32eaa45b99284fdafc15b6b5c54/src/desota/detools.py#L279)

    Get Question-Answer Arguments from DeSOTA Model request

---

* [detools.get_request_url](https://github.com/DeSOTAai/pip/blob/7bcc88958e23d32eaa45b99284fdafc15b6b5c54/src/desota/detools.py#L332)

    Get URL Arguments from DeSOTA Model request

---

* [detools.get_request_html](https://github.com/DeSOTAai/pip/blob/7bcc88958e23d32eaa45b99284fdafc15b6b5c54/src/desota/detools.py#L430)

    Get HTML Files from DeSOTA Model request

---
---